"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class BillingAccountIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___BillingAccountIamBindingXCondition = BillingAccountIamBindingXCondition

@typing_extensions.final
class BillingAccountIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    @property
    def condition(self) -> global___BillingAccountIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        condition: global___BillingAccountIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["billing_account_id", b"billing_account_id", "condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___BillingAccountIamBinding = BillingAccountIamBinding

@typing_extensions.final
class BillingAccountIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___BillingAccountIamMemberXCondition = BillingAccountIamMemberXCondition

@typing_extensions.final
class BillingAccountIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___BillingAccountIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___BillingAccountIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["billing_account_id", b"billing_account_id", "condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___BillingAccountIamMember = BillingAccountIamMember

@typing_extensions.final
class BillingAccountIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["billing_account_id", b"billing_account_id", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info"]) -> None: ...

global___BillingAccountIamPolicy = BillingAccountIamPolicy

@typing_extensions.final
class BillingBudgetXAllUpdatesRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLE_DEFAULT_IAM_RECIPIENTS_FIELD_NUMBER: builtins.int
    MONITORING_NOTIFICATION_CHANNELS_FIELD_NUMBER: builtins.int
    PUBSUB_TOPIC_FIELD_NUMBER: builtins.int
    SCHEMA_VERSION_FIELD_NUMBER: builtins.int
    disable_default_iam_recipients: builtins.bool
    @property
    def monitoring_notification_channels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    pubsub_topic: builtins.str
    schema_version: builtins.str
    def __init__(
        self,
        *,
        disable_default_iam_recipients: builtins.bool = ...,
        monitoring_notification_channels: collections.abc.Iterable[builtins.str] | None = ...,
        pubsub_topic: builtins.str = ...,
        schema_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_default_iam_recipients", b"disable_default_iam_recipients", "monitoring_notification_channels", b"monitoring_notification_channels", "pubsub_topic", b"pubsub_topic", "schema_version", b"schema_version"]) -> None: ...

global___BillingBudgetXAllUpdatesRule = BillingBudgetXAllUpdatesRule

@typing_extensions.final
class BillingBudgetXAmountXSpecifiedAmount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENCY_CODE_FIELD_NUMBER: builtins.int
    NANOS_FIELD_NUMBER: builtins.int
    UNITS_FIELD_NUMBER: builtins.int
    currency_code: builtins.str
    nanos: builtins.float
    units: builtins.str
    def __init__(
        self,
        *,
        currency_code: builtins.str = ...,
        nanos: builtins.float = ...,
        units: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["currency_code", b"currency_code", "nanos", b"nanos", "units", b"units"]) -> None: ...

global___BillingBudgetXAmountXSpecifiedAmount = BillingBudgetXAmountXSpecifiedAmount

@typing_extensions.final
class BillingBudgetXAmount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_PERIOD_AMOUNT_FIELD_NUMBER: builtins.int
    SPECIFIED_AMOUNT_FIELD_NUMBER: builtins.int
    last_period_amount: builtins.bool
    @property
    def specified_amount(self) -> global___BillingBudgetXAmountXSpecifiedAmount: ...
    def __init__(
        self,
        *,
        last_period_amount: builtins.bool = ...,
        specified_amount: global___BillingBudgetXAmountXSpecifiedAmount | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["specified_amount", b"specified_amount"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_period_amount", b"last_period_amount", "specified_amount", b"specified_amount"]) -> None: ...

global___BillingBudgetXAmount = BillingBudgetXAmount

@typing_extensions.final
class BillingBudgetXBudgetFilterXCustomPeriodXEndDate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    day: builtins.float
    month: builtins.float
    year: builtins.float
    def __init__(
        self,
        *,
        day: builtins.float = ...,
        month: builtins.float = ...,
        year: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day", b"day", "month", b"month", "year", b"year"]) -> None: ...

global___BillingBudgetXBudgetFilterXCustomPeriodXEndDate = BillingBudgetXBudgetFilterXCustomPeriodXEndDate

@typing_extensions.final
class BillingBudgetXBudgetFilterXCustomPeriodXStartDate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    day: builtins.float
    month: builtins.float
    year: builtins.float
    def __init__(
        self,
        *,
        day: builtins.float = ...,
        month: builtins.float = ...,
        year: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day", b"day", "month", b"month", "year", b"year"]) -> None: ...

global___BillingBudgetXBudgetFilterXCustomPeriodXStartDate = BillingBudgetXBudgetFilterXCustomPeriodXStartDate

@typing_extensions.final
class BillingBudgetXBudgetFilterXCustomPeriod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    END_DATE_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    @property
    def end_date(self) -> global___BillingBudgetXBudgetFilterXCustomPeriodXEndDate: ...
    @property
    def start_date(self) -> global___BillingBudgetXBudgetFilterXCustomPeriodXStartDate: ...
    def __init__(
        self,
        *,
        end_date: global___BillingBudgetXBudgetFilterXCustomPeriodXEndDate | None = ...,
        start_date: global___BillingBudgetXBudgetFilterXCustomPeriodXStartDate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_date", b"end_date", "start_date", b"start_date"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_date", b"end_date", "start_date", b"start_date"]) -> None: ...

global___BillingBudgetXBudgetFilterXCustomPeriod = BillingBudgetXBudgetFilterXCustomPeriod

@typing_extensions.final
class BillingBudgetXBudgetFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CALENDAR_PERIOD_FIELD_NUMBER: builtins.int
    CREDIT_TYPES_FIELD_NUMBER: builtins.int
    CREDIT_TYPES_TREATMENT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    PROJECTS_FIELD_NUMBER: builtins.int
    SERVICES_FIELD_NUMBER: builtins.int
    SUBACCOUNTS_FIELD_NUMBER: builtins.int
    CUSTOM_PERIOD_FIELD_NUMBER: builtins.int
    calendar_period: builtins.str
    @property
    def credit_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    credit_types_treatment: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def projects(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def subaccounts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def custom_period(self) -> global___BillingBudgetXBudgetFilterXCustomPeriod: ...
    def __init__(
        self,
        *,
        calendar_period: builtins.str = ...,
        credit_types: collections.abc.Iterable[builtins.str] | None = ...,
        credit_types_treatment: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        projects: collections.abc.Iterable[builtins.str] | None = ...,
        services: collections.abc.Iterable[builtins.str] | None = ...,
        subaccounts: collections.abc.Iterable[builtins.str] | None = ...,
        custom_period: global___BillingBudgetXBudgetFilterXCustomPeriod | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["custom_period", b"custom_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["calendar_period", b"calendar_period", "credit_types", b"credit_types", "credit_types_treatment", b"credit_types_treatment", "custom_period", b"custom_period", "labels", b"labels", "projects", b"projects", "services", b"services", "subaccounts", b"subaccounts"]) -> None: ...

global___BillingBudgetXBudgetFilter = BillingBudgetXBudgetFilter

@typing_extensions.final
class BillingBudgetXThresholdRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEND_BASIS_FIELD_NUMBER: builtins.int
    THRESHOLD_PERCENT_FIELD_NUMBER: builtins.int
    spend_basis: builtins.str
    threshold_percent: builtins.float
    def __init__(
        self,
        *,
        spend_basis: builtins.str = ...,
        threshold_percent: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["spend_basis", b"spend_basis", "threshold_percent", b"threshold_percent"]) -> None: ...

global___BillingBudgetXThresholdRules = BillingBudgetXThresholdRules

@typing_extensions.final
class BillingBudgetXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___BillingBudgetXTimeouts = BillingBudgetXTimeouts

@typing_extensions.final
class BillingBudget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALL_UPDATES_RULE_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    BUDGET_FILTER_FIELD_NUMBER: builtins.int
    THRESHOLD_RULES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account: builtins.str
    display_name: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def all_updates_rule(self) -> global___BillingBudgetXAllUpdatesRule: ...
    @property
    def amount(self) -> global___BillingBudgetXAmount: ...
    @property
    def budget_filter(self) -> global___BillingBudgetXBudgetFilter: ...
    @property
    def threshold_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BillingBudgetXThresholdRules]: ...
    @property
    def timeouts(self) -> global___BillingBudgetXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        all_updates_rule: global___BillingBudgetXAllUpdatesRule | None = ...,
        amount: global___BillingBudgetXAmount | None = ...,
        budget_filter: global___BillingBudgetXBudgetFilter | None = ...,
        threshold_rules: collections.abc.Iterable[global___BillingBudgetXThresholdRules] | None = ...,
        timeouts: global___BillingBudgetXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["all_updates_rule", b"all_updates_rule", "amount", b"amount", "budget_filter", b"budget_filter", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_updates_rule", b"all_updates_rule", "amount", b"amount", "billing_account", b"billing_account", "budget_filter", b"budget_filter", "display_name", b"display_name", "id", b"id", "name", b"name", "resource_info", b"resource_info", "threshold_rules", b"threshold_rules", "timeouts", b"timeouts"]) -> None: ...

global___BillingBudget = BillingBudget

@typing_extensions.final
class BillingSubaccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DELETION_POLICY_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MASTER_BILLING_ACCOUNT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPEN_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    deletion_policy: builtins.str
    display_name: builtins.str
    id: builtins.str
    master_billing_account: builtins.str
    name: builtins.str
    open: builtins.bool
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        deletion_policy: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        master_billing_account: builtins.str = ...,
        name: builtins.str = ...,
        open: builtins.bool = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["billing_account_id", b"billing_account_id", "deletion_policy", b"deletion_policy", "display_name", b"display_name", "id", b"id", "master_billing_account", b"master_billing_account", "name", b"name", "open", b"open", "resource_info", b"resource_info"]) -> None: ...

global___BillingSubaccount = BillingSubaccount



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_servicediscovery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61ws/aws_servicediscovery.proto\x12 oak9.tython.aws.servicediscovery\x1a\x13shared/shared.proto\"\xe1\x01\n\rHttpNamespace\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12G\n\x04tags\x18\x03 \x03(\x0b\x32\x39.oak9.tython.aws.servicediscovery.HttpNamespace.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xff\x02\n\x10ServiceDiscovery\x12G\n\x0ehttp_namespace\x18\x01 \x03(\x0b\x32/.oak9.tython.aws.servicediscovery.HttpNamespace\x12<\n\x08instance\x18\x02 \x03(\x0b\x32*.oak9.tython.aws.servicediscovery.Instance\x12T\n\x15private_dns_namespace\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.servicediscovery.PrivateDnsNamespace\x12R\n\x14public_dns_namespace\x18\x04 \x03(\x0b\x32\x34.oak9.tython.aws.servicediscovery.PublicDnsNamespace\x12:\n\x07service\x18\x05 \x03(\x0b\x32).oak9.tython.aws.servicediscovery.Service\"\x88\x02\n\x08Instance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12_\n\x13instance_attributes\x18\x02 \x03(\x0b\x32\x42.oak9.tython.aws.servicediscovery.Instance.InstanceAttributesEntry\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x12\n\nservice_id\x18\x04 \x01(\t\x1a\x39\n\x17InstanceAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfa\x01\n\x13PrivateDnsNamespace\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03vpc\x18\x03 \x01(\t\x12M\n\x04tags\x18\x04 \x03(\x0b\x32?.oak9.tython.aws.servicediscovery.PrivateDnsNamespace.TagsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x01\n\x12PublicDnsNamespace\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12L\n\x04tags\x18\x03 \x03(\x0b\x32>.oak9.tython.aws.servicediscovery.PublicDnsNamespace.TagsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\x1eServiceHealthCheckCustomConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x66\x61ilure_threshold\x18\x02 \x01(\x01\"X\n\x10ServiceDnsRecord\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03ttl\x18\x02 \x01(\x01\"\xc2\x01\n\x10ServiceDnsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12G\n\x0b\x64ns_records\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.servicediscovery.ServiceDnsRecord\x12\x16\n\x0erouting_policy\x18\x03 \x01(\t\x12\x14\n\x0cnamespace_id\x18\x04 \x01(\t\"\x85\x01\n\x18ServiceHealthCheckConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rresource_path\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61ilure_threshold\x18\x03 \x01(\x01\"\xf2\x03\n\x07Service\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x64\n\x1ahealth_check_custom_config\x18\x03 \x01(\x0b\x32@.oak9.tython.aws.servicediscovery.ServiceHealthCheckCustomConfig\x12\x46\n\ndns_config\x18\x04 \x01(\x0b\x32\x32.oak9.tython.aws.servicediscovery.ServiceDnsConfig\x12\x14\n\x0cnamespace_id\x18\x05 \x01(\t\x12W\n\x13health_check_config\x18\x06 \x01(\x0b\x32:.oak9.tython.aws.servicediscovery.ServiceHealthCheckConfig\x12\x41\n\x04tags\x18\x07 \x03(\x0b\x32\x33.oak9.tython.aws.servicediscovery.Service.TagsEntry\x12\x0c\n\x04name\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_servicediscovery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HTTPNAMESPACE_TAGSENTRY._options = None
  _HTTPNAMESPACE_TAGSENTRY._serialized_options = b'8\001'
  _INSTANCE_INSTANCEATTRIBUTESENTRY._options = None
  _INSTANCE_INSTANCEATTRIBUTESENTRY._serialized_options = b'8\001'
  _PRIVATEDNSNAMESPACE_TAGSENTRY._options = None
  _PRIVATEDNSNAMESPACE_TAGSENTRY._serialized_options = b'8\001'
  _PUBLICDNSNAMESPACE_TAGSENTRY._options = None
  _PUBLICDNSNAMESPACE_TAGSENTRY._serialized_options = b'8\001'
  _SERVICE_TAGSENTRY._options = None
  _SERVICE_TAGSENTRY._serialized_options = b'8\001'
  _HTTPNAMESPACE._serialized_start=90
  _HTTPNAMESPACE._serialized_end=315
  _HTTPNAMESPACE_TAGSENTRY._serialized_start=272
  _HTTPNAMESPACE_TAGSENTRY._serialized_end=315
  _SERVICEDISCOVERY._serialized_start=318
  _SERVICEDISCOVERY._serialized_end=701
  _INSTANCE._serialized_start=704
  _INSTANCE._serialized_end=968
  _INSTANCE_INSTANCEATTRIBUTESENTRY._serialized_start=911
  _INSTANCE_INSTANCEATTRIBUTESENTRY._serialized_end=968
  _PRIVATEDNSNAMESPACE._serialized_start=971
  _PRIVATEDNSNAMESPACE._serialized_end=1221
  _PRIVATEDNSNAMESPACE_TAGSENTRY._serialized_start=272
  _PRIVATEDNSNAMESPACE_TAGSENTRY._serialized_end=315
  _PUBLICDNSNAMESPACE._serialized_start=1224
  _PUBLICDNSNAMESPACE._serialized_end=1459
  _PUBLICDNSNAMESPACE_TAGSENTRY._serialized_start=272
  _PUBLICDNSNAMESPACE_TAGSENTRY._serialized_end=315
  _SERVICEHEALTHCHECKCUSTOMCONFIG._serialized_start=1461
  _SERVICEHEALTHCHECKCUSTOMCONFIG._serialized_end=1577
  _SERVICEDNSRECORD._serialized_start=1579
  _SERVICEDNSRECORD._serialized_end=1667
  _SERVICEDNSCONFIG._serialized_start=1670
  _SERVICEDNSCONFIG._serialized_end=1864
  _SERVICEHEALTHCHECKCONFIG._serialized_start=1867
  _SERVICEHEALTHCHECKCONFIG._serialized_end=2000
  _SERVICE._serialized_start=2003
  _SERVICE._serialized_end=2501
  _SERVICE_TAGSENTRY._serialized_start=272
  _SERVICE_TAGSENTRY._serialized_end=315
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_elasticloadbalancingv2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$aws/aws_elasticloadbalancingv2.proto\x12&oak9.tython.aws.elasticloadbalancingv2\x1a\x13shared/shared.proto\"}\n\x13ListenerCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x02 \x01(\t\x12\x14\n\x0clistener_arn\x18\x03 \x01(\t\"\xfb\x03\n!ListenerAuthenticateCognitoConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x9c\x01\n#authentication_request_extra_params\x18\x02 \x03(\x0b\x32o.oak9.tython.aws.elasticloadbalancingv2.ListenerAuthenticateCognitoConfig.AuthenticationRequestExtraParamsEntry\x12\"\n\x1aon_unauthenticated_request\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x1b\n\x13session_cookie_name\x18\x05 \x01(\t\x12\x17\n\x0fsession_timeout\x18\x06 \x01(\x05\x12\x15\n\ruser_pool_arn\x18\x07 \x01(\t\x12\x1b\n\x13user_pool_client_id\x18\x08 \x01(\t\x12\x18\n\x10user_pool_domain\x18\t \x01(\t\x1aG\n%AuthenticationRequestExtraParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb5\x04\n\x1eListenerAuthenticateOidcConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x99\x01\n#authentication_request_extra_params\x18\x02 \x03(\x0b\x32l.oak9.tython.aws.elasticloadbalancingv2.ListenerAuthenticateOidcConfig.AuthenticationRequestExtraParamsEntry\x12\x1e\n\x16\x61uthorization_endpoint\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x15\n\rclient_secret\x18\x05 \x01(\t\x12\x0e\n\x06issuer\x18\x06 \x01(\t\x12\"\n\x1aon_unauthenticated_request\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x1b\n\x13session_cookie_name\x18\t \x01(\t\x12\x17\n\x0fsession_timeout\x18\n \x01(\x05\x12\x16\n\x0etoken_endpoint\x18\x0b \x01(\t\x12\x1a\n\x12user_info_endpoint\x18\x0c \x01(\t\x1aG\n%AuthenticationRequestExtraParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x01\n\x1bListenerFixedResponseConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\t\x12\x14\n\x0cmessage_body\x18\x03 \x01(\t\x12\x13\n\x0bstatus_code\x18\x04 \x01(\t\"\x89\x01\n#ListenerTargetGroupStickinessConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x64uration_seconds\x18\x02 \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"}\n\x18ListenerTargetGroupTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10target_group_arn\x18\x02 \x01(\t\x12\x0e\n\x06weight\x18\x03 \x01(\x05\"\x9e\x02\n\x15ListenerForwardConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12s\n\x1etarget_group_stickiness_config\x18\x02 \x01(\x0b\x32K.oak9.tython.aws.elasticloadbalancingv2.ListenerTargetGroupStickinessConfig\x12W\n\rtarget_groups\x18\x03 \x03(\x0b\x32@.oak9.tython.aws.elasticloadbalancingv2.ListenerTargetGroupTuple\"\xb1\x01\n\x16ListenerRedirectConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\t\x12\x10\n\x08protocol\x18\x05 \x01(\t\x12\r\n\x05query\x18\x06 \x01(\t\x12\x13\n\x0bstatus_code\x18\x07 \x01(\t\"\x9b\x05\n\x0eListenerAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12n\n\x1b\x61uthenticate_cognito_config\x18\x02 \x01(\x0b\x32I.oak9.tython.aws.elasticloadbalancingv2.ListenerAuthenticateCognitoConfig\x12h\n\x18\x61uthenticate_oidc_config\x18\x03 \x01(\x0b\x32\x46.oak9.tython.aws.elasticloadbalancingv2.ListenerAuthenticateOidcConfig\x12\x62\n\x15\x66ixed_response_config\x18\x04 \x01(\x0b\x32\x43.oak9.tython.aws.elasticloadbalancingv2.ListenerFixedResponseConfig\x12U\n\x0e\x66orward_config\x18\x05 \x01(\x0b\x32=.oak9.tython.aws.elasticloadbalancingv2.ListenerForwardConfig\x12\r\n\x05order\x18\x06 \x01(\x05\x12W\n\x0fredirect_config\x18\x07 \x01(\x0b\x32>.oak9.tython.aws.elasticloadbalancingv2.ListenerRedirectConfig\x12\x18\n\x10target_group_arn\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\x12+\n#authentication_request_extra_params\x18\n \x01(\t\"\xe1\x02\n\x08Listener\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x61lpn_policy\x18\x02 \x03(\t\x12Q\n\x0c\x63\x65rtificates\x18\x03 \x03(\x0b\x32;.oak9.tython.aws.elasticloadbalancingv2.ListenerCertificate\x12O\n\x0f\x64\x65\x66\x61ult_actions\x18\x04 \x03(\x0b\x32\x36.oak9.tython.aws.elasticloadbalancingv2.ListenerAction\x12\x19\n\x11load_balancer_arn\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\x05\x12\x10\n\x08protocol\x18\x07 \x01(\t\x12\x12\n\nssl_policy\x18\x08 \x01(\t\x12\x14\n\x0clistener_arn\x18\t \x01(\t\"\x9c\x03\n\x16\x45lasticLoadBalancingV2\x12\x42\n\x08listener\x18\x01 \x03(\x0b\x32\x30.oak9.tython.aws.elasticloadbalancingv2.Listener\x12Y\n\x14listener_certificate\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.elasticloadbalancingv2.ListenerCertificate\x12K\n\rlistener_rule\x18\x03 \x03(\x0b\x32\x34.oak9.tython.aws.elasticloadbalancingv2.ListenerRule\x12K\n\rload_balancer\x18\x04 \x01(\x0b\x32\x34.oak9.tython.aws.elasticloadbalancingv2.LoadBalancer\x12I\n\x0ctarget_group\x18\x05 \x01(\x0b\x32\x33.oak9.tython.aws.elasticloadbalancingv2.TargetGroup\"r\n\x1eListenerCertificateCertificate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63\x65rtificate_arn\x18\x02 \x01(\t\"\x83\x04\n%ListenerRuleAuthenticateCognitoConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\xa0\x01\n#authentication_request_extra_params\x18\x02 \x03(\x0b\x32s.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleAuthenticateCognitoConfig.AuthenticationRequestExtraParamsEntry\x12\"\n\x1aon_unauthenticated_request\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x1b\n\x13session_cookie_name\x18\x05 \x01(\t\x12\x17\n\x0fsession_timeout\x18\x06 \x01(\x05\x12\x15\n\ruser_pool_arn\x18\x07 \x01(\t\x12\x1b\n\x13user_pool_client_id\x18\x08 \x01(\t\x12\x18\n\x10user_pool_domain\x18\t \x01(\t\x1aG\n%AuthenticationRequestExtraParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbd\x04\n\"ListenerRuleAuthenticateOidcConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x9d\x01\n#authentication_request_extra_params\x18\x02 \x03(\x0b\x32p.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleAuthenticateOidcConfig.AuthenticationRequestExtraParamsEntry\x12\x1e\n\x16\x61uthorization_endpoint\x18\x03 \x01(\t\x12\x11\n\tclient_id\x18\x04 \x01(\t\x12\x15\n\rclient_secret\x18\x05 \x01(\t\x12\x0e\n\x06issuer\x18\x06 \x01(\t\x12\"\n\x1aon_unauthenticated_request\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x1b\n\x13session_cookie_name\x18\t \x01(\t\x12\x17\n\x0fsession_timeout\x18\n \x01(\x05\x12\x16\n\x0etoken_endpoint\x18\x0b \x01(\t\x12\x1a\n\x12user_info_endpoint\x18\x0c \x01(\t\x1aG\n%AuthenticationRequestExtraParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9b\x01\n\x1fListenerRuleFixedResponseConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63ontent_type\x18\x02 \x01(\t\x12\x14\n\x0cmessage_body\x18\x03 \x01(\t\x12\x13\n\x0bstatus_code\x18\x04 \x01(\t\"\x8d\x01\n\'ListenerRuleTargetGroupStickinessConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x64uration_seconds\x18\x02 \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"\x81\x01\n\x1cListenerRuleTargetGroupTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10target_group_arn\x18\x02 \x01(\t\x12\x0e\n\x06weight\x18\x03 \x01(\x05\"\xaa\x02\n\x19ListenerRuleForwardConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12w\n\x1etarget_group_stickiness_config\x18\x02 \x01(\x0b\x32O.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleTargetGroupStickinessConfig\x12[\n\rtarget_groups\x18\x03 \x03(\x0b\x32\x44.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleTargetGroupTuple\"\xb5\x01\n\x1aListenerRuleRedirectConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\t\x12\x10\n\x08protocol\x18\x05 \x01(\t\x12\r\n\x05query\x18\x06 \x01(\t\x12\x13\n\x0bstatus_code\x18\x07 \x01(\t\"\x86\x05\n\x12ListenerRuleAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12r\n\x1b\x61uthenticate_cognito_config\x18\x02 \x01(\x0b\x32M.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleAuthenticateCognitoConfig\x12l\n\x18\x61uthenticate_oidc_config\x18\x03 \x01(\x0b\x32J.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleAuthenticateOidcConfig\x12\x66\n\x15\x66ixed_response_config\x18\x04 \x01(\x0b\x32G.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleFixedResponseConfig\x12Y\n\x0e\x66orward_config\x18\x05 \x01(\x0b\x32\x41.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleForwardConfig\x12\r\n\x05order\x18\x06 \x01(\x05\x12[\n\x0fredirect_config\x18\x07 \x01(\x0b\x32\x42.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleRedirectConfig\x12\x18\n\x10target_group_arn\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\"g\n\x1cListenerRuleHostHeaderConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\"\x81\x01\n\x1cListenerRuleHttpHeaderConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10http_header_name\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"n\n#ListenerRuleHttpRequestMethodConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\"h\n\x1dListenerRulePathPatternConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\"v\n\x1fListenerRuleQueryStringKeyValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xb1\x01\n\x1dListenerRuleQueryStringConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x06values\x18\x02 \x03(\x0b\x32G.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleQueryStringKeyValue\"e\n\x1aListenerRuleSourceIpConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xce\x05\n\x19ListenerRuleRuleCondition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x66ield\x18\x02 \x01(\t\x12`\n\x12host_header_config\x18\x03 \x01(\x0b\x32\x44.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleHostHeaderConfig\x12`\n\x12http_header_config\x18\x04 \x01(\x0b\x32\x44.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleHttpHeaderConfig\x12o\n\x1ahttp_request_method_config\x18\x05 \x01(\x0b\x32K.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleHttpRequestMethodConfig\x12\x62\n\x13path_pattern_config\x18\x06 \x01(\x0b\x32\x45.oak9.tython.aws.elasticloadbalancingv2.ListenerRulePathPatternConfig\x12\x62\n\x13query_string_config\x18\x07 \x01(\x0b\x32\x45.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleQueryStringConfig\x12\\\n\x10source_ip_config\x18\x08 \x01(\x0b\x32\x42.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleSourceIpConfig\x12\x0e\n\x06values\x18\t \x03(\t\"\x93\x02\n\x0cListenerRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32:.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleAction\x12U\n\nconditions\x18\x03 \x03(\x0b\x32\x41.oak9.tython.aws.elasticloadbalancingv2.ListenerRuleRuleCondition\x12\x14\n\x0clistener_arn\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\"x\n!LoadBalancerLoadBalancerAttribute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x9c\x01\n\x19LoadBalancerSubnetMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rallocation_id\x18\x02 \x01(\t\x12\x1c\n\x14private_ipv4_address\x18\x03 \x01(\t\x12\x11\n\tsubnet_id\x18\x04 \x01(\t\"\xfa\x03\n\x0cLoadBalancer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fip_address_type\x18\x02 \x01(\t\x12k\n\x18load_balancer_attributes\x18\x03 \x03(\x0b\x32I.oak9.tython.aws.elasticloadbalancingv2.LoadBalancerLoadBalancerAttribute\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06scheme\x18\x05 \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x06 \x03(\t\x12Z\n\x0fsubnet_mappings\x18\x07 \x03(\x0b\x32\x41.oak9.tython.aws.elasticloadbalancingv2.LoadBalancerSubnetMapping\x12\x0f\n\x07subnets\x18\x08 \x03(\t\x12L\n\x04tags\x18\t \x03(\x0b\x32>.oak9.tython.aws.elasticloadbalancingv2.LoadBalancer.TagsEntry\x12\x0c\n\x04type\x18\n \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n\x12TargetGroupMatcher\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\thttp_code\x18\x02 \x01(\t\"v\n\x1fTargetGroupTargetGroupAttribute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x8c\x01\n\x1cTargetGroupTargetDescription\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61vailability_zone\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\"\xa5\x06\n\x0bTargetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14health_check_enabled\x18\x02 \x01(\x08\x12%\n\x1dhealth_check_interval_seconds\x18\x03 \x01(\x05\x12\x19\n\x11health_check_path\x18\x04 \x01(\t\x12\x19\n\x11health_check_port\x18\x05 \x01(\t\x12\x1d\n\x15health_check_protocol\x18\x06 \x01(\t\x12$\n\x1chealth_check_timeout_seconds\x18\x07 \x01(\x05\x12\x1f\n\x17healthy_threshold_count\x18\x08 \x01(\x05\x12K\n\x07matcher\x18\t \x01(\x0b\x32:.oak9.tython.aws.elasticloadbalancingv2.TargetGroupMatcher\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0c\n\x04port\x18\x0b \x01(\x05\x12\x10\n\x08protocol\x18\x0c \x01(\t\x12K\n\x04tags\x18\r \x03(\x0b\x32=.oak9.tython.aws.elasticloadbalancingv2.TargetGroup.TagsEntry\x12h\n\x17target_group_attributes\x18\x0e \x03(\x0b\x32G.oak9.tython.aws.elasticloadbalancingv2.TargetGroupTargetGroupAttribute\x12\x13\n\x0btarget_type\x18\x0f \x01(\t\x12U\n\x07targets\x18\x10 \x03(\x0b\x32\x44.oak9.tython.aws.elasticloadbalancingv2.TargetGroupTargetDescription\x12!\n\x19unhealthy_threshold_count\x18\x11 \x01(\x05\x12\x0e\n\x06vpc_id\x18\x12 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_elasticloadbalancingv2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LISTENERAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._options = None
  _LISTENERAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_options = b'8\001'
  _LISTENERAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._options = None
  _LISTENERAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_options = b'8\001'
  _LISTENERRULEAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._options = None
  _LISTENERRULEAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_options = b'8\001'
  _LISTENERRULEAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._options = None
  _LISTENERRULEAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_options = b'8\001'
  _LOADBALANCER_TAGSENTRY._options = None
  _LOADBALANCER_TAGSENTRY._serialized_options = b'8\001'
  _TARGETGROUP_TAGSENTRY._options = None
  _TARGETGROUP_TAGSENTRY._serialized_options = b'8\001'
  _LISTENERCERTIFICATE._serialized_start=101
  _LISTENERCERTIFICATE._serialized_end=226
  _LISTENERAUTHENTICATECOGNITOCONFIG._serialized_start=229
  _LISTENERAUTHENTICATECOGNITOCONFIG._serialized_end=736
  _LISTENERAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_start=665
  _LISTENERAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_end=736
  _LISTENERAUTHENTICATEOIDCCONFIG._serialized_start=739
  _LISTENERAUTHENTICATEOIDCCONFIG._serialized_end=1304
  _LISTENERAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_start=665
  _LISTENERAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_end=736
  _LISTENERFIXEDRESPONSECONFIG._serialized_start=1307
  _LISTENERFIXEDRESPONSECONFIG._serialized_end=1458
  _LISTENERTARGETGROUPSTICKINESSCONFIG._serialized_start=1461
  _LISTENERTARGETGROUPSTICKINESSCONFIG._serialized_end=1598
  _LISTENERTARGETGROUPTUPLE._serialized_start=1600
  _LISTENERTARGETGROUPTUPLE._serialized_end=1725
  _LISTENERFORWARDCONFIG._serialized_start=1728
  _LISTENERFORWARDCONFIG._serialized_end=2014
  _LISTENERREDIRECTCONFIG._serialized_start=2017
  _LISTENERREDIRECTCONFIG._serialized_end=2194
  _LISTENERACTION._serialized_start=2197
  _LISTENERACTION._serialized_end=2864
  _LISTENER._serialized_start=2867
  _LISTENER._serialized_end=3220
  _ELASTICLOADBALANCINGV2._serialized_start=3223
  _ELASTICLOADBALANCINGV2._serialized_end=3635
  _LISTENERCERTIFICATECERTIFICATE._serialized_start=3637
  _LISTENERCERTIFICATECERTIFICATE._serialized_end=3751
  _LISTENERRULEAUTHENTICATECOGNITOCONFIG._serialized_start=3754
  _LISTENERRULEAUTHENTICATECOGNITOCONFIG._serialized_end=4269
  _LISTENERRULEAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_start=665
  _LISTENERRULEAUTHENTICATECOGNITOCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_end=736
  _LISTENERRULEAUTHENTICATEOIDCCONFIG._serialized_start=4272
  _LISTENERRULEAUTHENTICATEOIDCCONFIG._serialized_end=4845
  _LISTENERRULEAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_start=665
  _LISTENERRULEAUTHENTICATEOIDCCONFIG_AUTHENTICATIONREQUESTEXTRAPARAMSENTRY._serialized_end=736
  _LISTENERRULEFIXEDRESPONSECONFIG._serialized_start=4848
  _LISTENERRULEFIXEDRESPONSECONFIG._serialized_end=5003
  _LISTENERRULETARGETGROUPSTICKINESSCONFIG._serialized_start=5006
  _LISTENERRULETARGETGROUPSTICKINESSCONFIG._serialized_end=5147
  _LISTENERRULETARGETGROUPTUPLE._serialized_start=5150
  _LISTENERRULETARGETGROUPTUPLE._serialized_end=5279
  _LISTENERRULEFORWARDCONFIG._serialized_start=5282
  _LISTENERRULEFORWARDCONFIG._serialized_end=5580
  _LISTENERRULEREDIRECTCONFIG._serialized_start=5583
  _LISTENERRULEREDIRECTCONFIG._serialized_end=5764
  _LISTENERRULEACTION._serialized_start=5767
  _LISTENERRULEACTION._serialized_end=6413
  _LISTENERRULEHOSTHEADERCONFIG._serialized_start=6415
  _LISTENERRULEHOSTHEADERCONFIG._serialized_end=6518
  _LISTENERRULEHTTPHEADERCONFIG._serialized_start=6521
  _LISTENERRULEHTTPHEADERCONFIG._serialized_end=6650
  _LISTENERRULEHTTPREQUESTMETHODCONFIG._serialized_start=6652
  _LISTENERRULEHTTPREQUESTMETHODCONFIG._serialized_end=6762
  _LISTENERRULEPATHPATTERNCONFIG._serialized_start=6764
  _LISTENERRULEPATHPATTERNCONFIG._serialized_end=6868
  _LISTENERRULEQUERYSTRINGKEYVALUE._serialized_start=6870
  _LISTENERRULEQUERYSTRINGKEYVALUE._serialized_end=6988
  _LISTENERRULEQUERYSTRINGCONFIG._serialized_start=6991
  _LISTENERRULEQUERYSTRINGCONFIG._serialized_end=7168
  _LISTENERRULESOURCEIPCONFIG._serialized_start=7170
  _LISTENERRULESOURCEIPCONFIG._serialized_end=7271
  _LISTENERRULERULECONDITION._serialized_start=7274
  _LISTENERRULERULECONDITION._serialized_end=7992
  _LISTENERRULE._serialized_start=7995
  _LISTENERRULE._serialized_end=8270
  _LOADBALANCERLOADBALANCERATTRIBUTE._serialized_start=8272
  _LOADBALANCERLOADBALANCERATTRIBUTE._serialized_end=8392
  _LOADBALANCERSUBNETMAPPING._serialized_start=8395
  _LOADBALANCERSUBNETMAPPING._serialized_end=8551
  _LOADBALANCER._serialized_start=8554
  _LOADBALANCER._serialized_end=9060
  _LOADBALANCER_TAGSENTRY._serialized_start=9017
  _LOADBALANCER_TAGSENTRY._serialized_end=9060
  _TARGETGROUPMATCHER._serialized_start=9062
  _TARGETGROUPMATCHER._serialized_end=9158
  _TARGETGROUPTARGETGROUPATTRIBUTE._serialized_start=9160
  _TARGETGROUPTARGETGROUPATTRIBUTE._serialized_end=9278
  _TARGETGROUPTARGETDESCRIPTION._serialized_start=9281
  _TARGETGROUPTARGETDESCRIPTION._serialized_end=9421
  _TARGETGROUP._serialized_start=9424
  _TARGETGROUP._serialized_end=10229
  _TARGETGROUP_TAGSENTRY._serialized_start=9017
  _TARGETGROUP_TAGSENTRY._serialized_end=9060
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_active.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gcp/gcp_active.proto\x12\x16oak9.tython.gcp.active\x1a\x13shared/shared.proto\"P\n\x1e\x41\x63tiveDirectoryDomainXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xbc\x03\n\x15\x41\x63tiveDirectoryDomain\x12\r\n\x05\x61\x64min\x18\x01 \x01(\t\x12\x1b\n\x13\x61uthorized_networks\x18\x02 \x03(\t\x12\x13\n\x0b\x64omain_name\x18\x03 \x01(\t\x12\x0c\n\x04\x66qdn\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12I\n\x06labels\x18\x06 \x03(\x0b\x32\x39.oak9.tython.gcp.active.ActiveDirectoryDomain.LabelsEntry\x12\x11\n\tlocations\x18\x07 \x03(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x19\n\x11reserved_ip_range\x18\n \x01(\t\x12H\n\x08timeouts\x18\x0b \x01(\x0b\x32\x36.oak9.tython.gcp.active.ActiveDirectoryDomainXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n#ActiveDirectoryDomainTrustXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xfd\x02\n\x1a\x41\x63tiveDirectoryDomainTrust\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12 \n\x18selective_authentication\x18\x04 \x01(\x08\x12\x1f\n\x17target_dns_ip_addresses\x18\x05 \x03(\t\x12\x1a\n\x12target_domain_name\x18\x06 \x01(\t\x12\x17\n\x0ftrust_direction\x18\x07 \x01(\t\x12\x1e\n\x16trust_handshake_secret\x18\x08 \x01(\t\x12\x12\n\ntrust_type\x18\t \x01(\t\x12M\n\x08timeouts\x18\n \x01(\x0b\x32;.oak9.tython.gcp.active.ActiveDirectoryDomainTrustXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_active_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACTIVEDIRECTORYDOMAIN_LABELSENTRY._options = None
  _ACTIVEDIRECTORYDOMAIN_LABELSENTRY._serialized_options = b'8\001'
  _ACTIVEDIRECTORYDOMAINXTIMEOUTS._serialized_start=69
  _ACTIVEDIRECTORYDOMAINXTIMEOUTS._serialized_end=149
  _ACTIVEDIRECTORYDOMAIN._serialized_start=152
  _ACTIVEDIRECTORYDOMAIN._serialized_end=596
  _ACTIVEDIRECTORYDOMAIN_LABELSENTRY._serialized_start=551
  _ACTIVEDIRECTORYDOMAIN_LABELSENTRY._serialized_end=596
  _ACTIVEDIRECTORYDOMAINTRUSTXTIMEOUTS._serialized_start=598
  _ACTIVEDIRECTORYDOMAINTRUSTXTIMEOUTS._serialized_end=683
  _ACTIVEDIRECTORYDOMAINTRUST._serialized_start=686
  _ACTIVEDIRECTORYDOMAINTRUST._serialized_end=1067
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_ServiceBus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACES_FIELD_NUMBER: builtins.int
    NAMESPACES_QUEUES_FIELD_NUMBER: builtins.int
    NAMESPACES_TOPICS_FIELD_NUMBER: builtins.int
    @property
    def namespaces(self) -> global___Namespaces: ...
    @property
    def namespaces_queues(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesQueues]: ...
    @property
    def namespaces_topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesTopics]: ...
    def __init__(
        self,
        *,
        namespaces: global___Namespaces | None = ...,
        namespaces_queues: collections.abc.Iterable[global___NamespacesQueues] | None = ...,
        namespaces_topics: collections.abc.Iterable[global___NamespacesTopics] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["namespaces", b"namespaces"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespaces", b"namespaces", "namespaces_queues", b"namespaces_queues", "namespaces_topics", b"namespaces_topics"]) -> None: ...

global___Microsoft_ServiceBus = Microsoft_ServiceBus

@typing_extensions.final
class NamespacesTopicsSubscriptionsRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    CORRELATION_FILTER_FIELD_NUMBER: builtins.int
    FILTER_TYPE_FIELD_NUMBER: builtins.int
    SQL_FILTER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def action(self) -> global___Action: ...
    @property
    def correlation_filter(self) -> global___CorrelationFilter: ...
    filter_type: builtins.str
    @property
    def sql_filter(self) -> global___SqlFilter: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        action: global___Action | None = ...,
        correlation_filter: global___CorrelationFilter | None = ...,
        filter_type: builtins.str = ...,
        sql_filter: global___SqlFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action", "correlation_filter", b"correlation_filter", "resource_info", b"resource_info", "sql_filter", b"sql_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "correlation_filter", b"correlation_filter", "filter_type", b"filter_type", "name", b"name", "resource_info", b"resource_info", "sql_filter", b"sql_filter"]) -> None: ...

global___NamespacesTopicsSubscriptionsRules = NamespacesTopicsSubscriptionsRules

@typing_extensions.final
class SqlFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPATIBILITY_LEVEL_FIELD_NUMBER: builtins.int
    REQUIRES_PREPROCESSING_FIELD_NUMBER: builtins.int
    SQL_EXPRESSION_FIELD_NUMBER: builtins.int
    compatibility_level: builtins.int
    requires_preprocessing: builtins.bool
    sql_expression: builtins.str
    def __init__(
        self,
        *,
        compatibility_level: builtins.int = ...,
        requires_preprocessing: builtins.bool = ...,
        sql_expression: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["compatibility_level", b"compatibility_level", "requires_preprocessing", b"requires_preprocessing", "sql_expression", b"sql_expression"]) -> None: ...

global___SqlFilter = SqlFilter

@typing_extensions.final
class CorrelationFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    MESSAGE_ID_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    REPLY_TO_FIELD_NUMBER: builtins.int
    REPLY_TO_SESSION_ID_FIELD_NUMBER: builtins.int
    REQUIRES_PREPROCESSING_FIELD_NUMBER: builtins.int
    SESSION_ID_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    content_type: builtins.str
    correlation_id: builtins.str
    label: builtins.str
    message_id: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    reply_to: builtins.str
    reply_to_session_id: builtins.str
    requires_preprocessing: builtins.bool
    session_id: builtins.str
    to: builtins.str
    def __init__(
        self,
        *,
        content_type: builtins.str = ...,
        correlation_id: builtins.str = ...,
        label: builtins.str = ...,
        message_id: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        reply_to: builtins.str = ...,
        reply_to_session_id: builtins.str = ...,
        requires_preprocessing: builtins.bool = ...,
        session_id: builtins.str = ...,
        to: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_type", b"content_type", "correlation_id", b"correlation_id", "label", b"label", "message_id", b"message_id", "properties", b"properties", "reply_to", b"reply_to", "reply_to_session_id", b"reply_to_session_id", "requires_preprocessing", b"requires_preprocessing", "session_id", b"session_id", "to", b"to"]) -> None: ...

global___CorrelationFilter = CorrelationFilter

@typing_extensions.final
class Action(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPATIBILITY_LEVEL_FIELD_NUMBER: builtins.int
    REQUIRES_PREPROCESSING_FIELD_NUMBER: builtins.int
    SQL_EXPRESSION_FIELD_NUMBER: builtins.int
    compatibility_level: builtins.int
    requires_preprocessing: builtins.bool
    sql_expression: builtins.str
    def __init__(
        self,
        *,
        compatibility_level: builtins.int = ...,
        requires_preprocessing: builtins.bool = ...,
        sql_expression: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["compatibility_level", b"compatibility_level", "requires_preprocessing", b"requires_preprocessing", "sql_expression", b"sql_expression"]) -> None: ...

global___Action = Action

@typing_extensions.final
class NamespacesTopicsSubscriptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_DELETE_ON_IDLE_FIELD_NUMBER: builtins.int
    CLIENT_AFFINE_PROPERTIES_FIELD_NUMBER: builtins.int
    DEAD_LETTERING_ON_FILTER_EVALUATION_EXCEPTIONS_FIELD_NUMBER: builtins.int
    DEAD_LETTERING_ON_MESSAGE_EXPIRATION_FIELD_NUMBER: builtins.int
    DEFAULT_MESSAGE_TIME_TO_LIVE_FIELD_NUMBER: builtins.int
    DUPLICATE_DETECTION_HISTORY_TIME_WINDOW_FIELD_NUMBER: builtins.int
    ENABLE_BATCHED_OPERATIONS_FIELD_NUMBER: builtins.int
    FORWARD_DEAD_LETTERED_MESSAGES_TO_FIELD_NUMBER: builtins.int
    FORWARD_TO_FIELD_NUMBER: builtins.int
    IS_CLIENT_AFFINE_FIELD_NUMBER: builtins.int
    LOCK_DURATION_FIELD_NUMBER: builtins.int
    MAX_DELIVERY_COUNT_FIELD_NUMBER: builtins.int
    REQUIRES_SESSION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAMESPACES_TOPICS_SUBSCRIPTIONS_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    auto_delete_on_idle: builtins.str
    @property
    def client_affine_properties(self) -> global___SBClientAffineProperties: ...
    dead_lettering_on_filter_evaluation_exceptions: builtins.bool
    dead_lettering_on_message_expiration: builtins.bool
    default_message_time_to_live: builtins.str
    duplicate_detection_history_time_window: builtins.str
    enable_batched_operations: builtins.bool
    forward_dead_lettered_messages_to: builtins.str
    forward_to: builtins.str
    is_client_affine: builtins.bool
    lock_duration: builtins.str
    max_delivery_count: builtins.int
    requires_session: builtins.bool
    status: builtins.str
    @property
    def namespaces_topics_subscriptions_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesTopicsSubscriptionsRules]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        auto_delete_on_idle: builtins.str = ...,
        client_affine_properties: global___SBClientAffineProperties | None = ...,
        dead_lettering_on_filter_evaluation_exceptions: builtins.bool = ...,
        dead_lettering_on_message_expiration: builtins.bool = ...,
        default_message_time_to_live: builtins.str = ...,
        duplicate_detection_history_time_window: builtins.str = ...,
        enable_batched_operations: builtins.bool = ...,
        forward_dead_lettered_messages_to: builtins.str = ...,
        forward_to: builtins.str = ...,
        is_client_affine: builtins.bool = ...,
        lock_duration: builtins.str = ...,
        max_delivery_count: builtins.int = ...,
        requires_session: builtins.bool = ...,
        status: builtins.str = ...,
        namespaces_topics_subscriptions_rules: collections.abc.Iterable[global___NamespacesTopicsSubscriptionsRules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_affine_properties", b"client_affine_properties", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete_on_idle", b"auto_delete_on_idle", "client_affine_properties", b"client_affine_properties", "dead_lettering_on_filter_evaluation_exceptions", b"dead_lettering_on_filter_evaluation_exceptions", "dead_lettering_on_message_expiration", b"dead_lettering_on_message_expiration", "default_message_time_to_live", b"default_message_time_to_live", "duplicate_detection_history_time_window", b"duplicate_detection_history_time_window", "enable_batched_operations", b"enable_batched_operations", "forward_dead_lettered_messages_to", b"forward_dead_lettered_messages_to", "forward_to", b"forward_to", "is_client_affine", b"is_client_affine", "lock_duration", b"lock_duration", "max_delivery_count", b"max_delivery_count", "name", b"name", "namespaces_topics_subscriptions_rules", b"namespaces_topics_subscriptions_rules", "requires_session", b"requires_session", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___NamespacesTopicsSubscriptions = NamespacesTopicsSubscriptions

@typing_extensions.final
class SBClientAffineProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    IS_DURABLE_FIELD_NUMBER: builtins.int
    IS_SHARED_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    is_durable: builtins.bool
    is_shared: builtins.bool
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        is_durable: builtins.bool = ...,
        is_shared: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "is_durable", b"is_durable", "is_shared", b"is_shared"]) -> None: ...

global___SBClientAffineProperties = SBClientAffineProperties

@typing_extensions.final
class NamespacesTopicsAuthorizationRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def rights(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        rights: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "rights", b"rights"]) -> None: ...

global___NamespacesTopicsAuthorizationRules = NamespacesTopicsAuthorizationRules

@typing_extensions.final
class NamespacesTopics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_DELETE_ON_IDLE_FIELD_NUMBER: builtins.int
    DEFAULT_MESSAGE_TIME_TO_LIVE_FIELD_NUMBER: builtins.int
    DUPLICATE_DETECTION_HISTORY_TIME_WINDOW_FIELD_NUMBER: builtins.int
    ENABLE_BATCHED_OPERATIONS_FIELD_NUMBER: builtins.int
    ENABLE_EXPRESS_FIELD_NUMBER: builtins.int
    ENABLE_PARTITIONING_FIELD_NUMBER: builtins.int
    MAX_MESSAGE_SIZE_IN_KILOBYTES_FIELD_NUMBER: builtins.int
    MAX_SIZE_IN_MEGABYTES_FIELD_NUMBER: builtins.int
    REQUIRES_DUPLICATE_DETECTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SUPPORT_ORDERING_FIELD_NUMBER: builtins.int
    NAMESPACES_TOPICS_AUTHORIZATION_RULES_FIELD_NUMBER: builtins.int
    NAMESPACES_TOPICS_SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    auto_delete_on_idle: builtins.str
    default_message_time_to_live: builtins.str
    duplicate_detection_history_time_window: builtins.str
    enable_batched_operations: builtins.bool
    enable_express: builtins.bool
    enable_partitioning: builtins.bool
    max_message_size_in_kilobytes: builtins.int
    max_size_in_megabytes: builtins.int
    requires_duplicate_detection: builtins.bool
    status: builtins.str
    support_ordering: builtins.bool
    @property
    def namespaces_topics_authorization_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesTopicsAuthorizationRules]: ...
    @property
    def namespaces_topics_subscriptions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesTopicsSubscriptions]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        auto_delete_on_idle: builtins.str = ...,
        default_message_time_to_live: builtins.str = ...,
        duplicate_detection_history_time_window: builtins.str = ...,
        enable_batched_operations: builtins.bool = ...,
        enable_express: builtins.bool = ...,
        enable_partitioning: builtins.bool = ...,
        max_message_size_in_kilobytes: builtins.int = ...,
        max_size_in_megabytes: builtins.int = ...,
        requires_duplicate_detection: builtins.bool = ...,
        status: builtins.str = ...,
        support_ordering: builtins.bool = ...,
        namespaces_topics_authorization_rules: collections.abc.Iterable[global___NamespacesTopicsAuthorizationRules] | None = ...,
        namespaces_topics_subscriptions: collections.abc.Iterable[global___NamespacesTopicsSubscriptions] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete_on_idle", b"auto_delete_on_idle", "default_message_time_to_live", b"default_message_time_to_live", "duplicate_detection_history_time_window", b"duplicate_detection_history_time_window", "enable_batched_operations", b"enable_batched_operations", "enable_express", b"enable_express", "enable_partitioning", b"enable_partitioning", "max_message_size_in_kilobytes", b"max_message_size_in_kilobytes", "max_size_in_megabytes", b"max_size_in_megabytes", "name", b"name", "namespaces_topics_authorization_rules", b"namespaces_topics_authorization_rules", "namespaces_topics_subscriptions", b"namespaces_topics_subscriptions", "requires_duplicate_detection", b"requires_duplicate_detection", "resource_info", b"resource_info", "status", b"status", "support_ordering", b"support_ordering"]) -> None: ...

global___NamespacesTopics = NamespacesTopics

@typing_extensions.final
class NamespacesQueuesAuthorizationRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def rights(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        rights: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "rights", b"rights"]) -> None: ...

global___NamespacesQueuesAuthorizationRules = NamespacesQueuesAuthorizationRules

@typing_extensions.final
class NamespacesQueues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_DELETE_ON_IDLE_FIELD_NUMBER: builtins.int
    DEAD_LETTERING_ON_MESSAGE_EXPIRATION_FIELD_NUMBER: builtins.int
    DEFAULT_MESSAGE_TIME_TO_LIVE_FIELD_NUMBER: builtins.int
    DUPLICATE_DETECTION_HISTORY_TIME_WINDOW_FIELD_NUMBER: builtins.int
    ENABLE_BATCHED_OPERATIONS_FIELD_NUMBER: builtins.int
    ENABLE_EXPRESS_FIELD_NUMBER: builtins.int
    ENABLE_PARTITIONING_FIELD_NUMBER: builtins.int
    FORWARD_DEAD_LETTERED_MESSAGES_TO_FIELD_NUMBER: builtins.int
    FORWARD_TO_FIELD_NUMBER: builtins.int
    LOCK_DURATION_FIELD_NUMBER: builtins.int
    MAX_DELIVERY_COUNT_FIELD_NUMBER: builtins.int
    MAX_MESSAGE_SIZE_IN_KILOBYTES_FIELD_NUMBER: builtins.int
    MAX_SIZE_IN_MEGABYTES_FIELD_NUMBER: builtins.int
    REQUIRES_DUPLICATE_DETECTION_FIELD_NUMBER: builtins.int
    REQUIRES_SESSION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    NAMESPACES_QUEUES_AUTHORIZATION_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    auto_delete_on_idle: builtins.str
    dead_lettering_on_message_expiration: builtins.bool
    default_message_time_to_live: builtins.str
    duplicate_detection_history_time_window: builtins.str
    enable_batched_operations: builtins.bool
    enable_express: builtins.bool
    enable_partitioning: builtins.bool
    forward_dead_lettered_messages_to: builtins.str
    forward_to: builtins.str
    lock_duration: builtins.str
    max_delivery_count: builtins.int
    max_message_size_in_kilobytes: builtins.int
    max_size_in_megabytes: builtins.int
    requires_duplicate_detection: builtins.bool
    requires_session: builtins.bool
    status: builtins.str
    @property
    def namespaces_queues_authorization_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesQueuesAuthorizationRules]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        auto_delete_on_idle: builtins.str = ...,
        dead_lettering_on_message_expiration: builtins.bool = ...,
        default_message_time_to_live: builtins.str = ...,
        duplicate_detection_history_time_window: builtins.str = ...,
        enable_batched_operations: builtins.bool = ...,
        enable_express: builtins.bool = ...,
        enable_partitioning: builtins.bool = ...,
        forward_dead_lettered_messages_to: builtins.str = ...,
        forward_to: builtins.str = ...,
        lock_duration: builtins.str = ...,
        max_delivery_count: builtins.int = ...,
        max_message_size_in_kilobytes: builtins.int = ...,
        max_size_in_megabytes: builtins.int = ...,
        requires_duplicate_detection: builtins.bool = ...,
        requires_session: builtins.bool = ...,
        status: builtins.str = ...,
        namespaces_queues_authorization_rules: collections.abc.Iterable[global___NamespacesQueuesAuthorizationRules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete_on_idle", b"auto_delete_on_idle", "dead_lettering_on_message_expiration", b"dead_lettering_on_message_expiration", "default_message_time_to_live", b"default_message_time_to_live", "duplicate_detection_history_time_window", b"duplicate_detection_history_time_window", "enable_batched_operations", b"enable_batched_operations", "enable_express", b"enable_express", "enable_partitioning", b"enable_partitioning", "forward_dead_lettered_messages_to", b"forward_dead_lettered_messages_to", "forward_to", b"forward_to", "lock_duration", b"lock_duration", "max_delivery_count", b"max_delivery_count", "max_message_size_in_kilobytes", b"max_message_size_in_kilobytes", "max_size_in_megabytes", b"max_size_in_megabytes", "name", b"name", "namespaces_queues_authorization_rules", b"namespaces_queues_authorization_rules", "requires_duplicate_detection", b"requires_duplicate_detection", "requires_session", b"requires_session", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___NamespacesQueues = NamespacesQueues

@typing_extensions.final
class NamespacesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___ConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___ConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___NamespacesPrivateEndpointConnections = NamespacesPrivateEndpointConnections

@typing_extensions.final
class NamespacesNetworkRuleSets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    IP_RULES_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    TRUSTED_SERVICE_ACCESS_ENABLED_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    default_action: builtins.str
    @property
    def ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NWRuleSetIpRules]: ...
    public_network_access: builtins.str
    trusted_service_access_enabled: builtins.bool
    @property
    def virtual_network_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NWRuleSetVirtualNetworkRules]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        default_action: builtins.str = ...,
        ip_rules: collections.abc.Iterable[global___NWRuleSetIpRules] | None = ...,
        public_network_access: builtins.str = ...,
        trusted_service_access_enabled: builtins.bool = ...,
        virtual_network_rules: collections.abc.Iterable[global___NWRuleSetVirtualNetworkRules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_action", b"default_action", "ip_rules", b"ip_rules", "name", b"name", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "trusted_service_access_enabled", b"trusted_service_access_enabled", "virtual_network_rules", b"virtual_network_rules"]) -> None: ...

global___NamespacesNetworkRuleSets = NamespacesNetworkRuleSets

@typing_extensions.final
class NWRuleSetVirtualNetworkRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IGNORE_MISSING_VNET_SERVICE_ENDPOINT_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    ignore_missing_vnet_service_endpoint: builtins.bool
    @property
    def subnet(self) -> global___Subnet: ...
    def __init__(
        self,
        *,
        ignore_missing_vnet_service_endpoint: builtins.bool = ...,
        subnet: global___Subnet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subnet", b"subnet"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ignore_missing_vnet_service_endpoint", b"ignore_missing_vnet_service_endpoint", "subnet", b"subnet"]) -> None: ...

global___NWRuleSetVirtualNetworkRules = NWRuleSetVirtualNetworkRules

@typing_extensions.final
class Subnet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___Subnet = Subnet

@typing_extensions.final
class NWRuleSetIpRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    IP_MASK_FIELD_NUMBER: builtins.int
    action: builtins.str
    ip_mask: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        ip_mask: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "ip_mask", b"ip_mask"]) -> None: ...

global___NWRuleSetIpRules = NWRuleSetIpRules

@typing_extensions.final
class NamespacesMigrationConfigurations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POST_MIGRATION_NAME_FIELD_NUMBER: builtins.int
    TARGET_NAMESPACE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    post_migration_name: builtins.str
    target_namespace: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        post_migration_name: builtins.str = ...,
        target_namespace: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "post_migration_name", b"post_migration_name", "resource_info", b"resource_info", "target_namespace", b"target_namespace"]) -> None: ...

global___NamespacesMigrationConfigurations = NamespacesMigrationConfigurations

@typing_extensions.final
class NamespacesDisasterRecoveryConfigs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALTERNATE_NAME_FIELD_NUMBER: builtins.int
    PARTNER_NAMESPACE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    alternate_name: builtins.str
    partner_namespace: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        alternate_name: builtins.str = ...,
        partner_namespace: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alternate_name", b"alternate_name", "name", b"name", "partner_namespace", b"partner_namespace", "resource_info", b"resource_info"]) -> None: ...

global___NamespacesDisasterRecoveryConfigs = NamespacesDisasterRecoveryConfigs

@typing_extensions.final
class NamespacesAuthorizationRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def rights(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        rights: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "rights", b"rights"]) -> None: ...

global___NamespacesAuthorizationRules = NamespacesAuthorizationRules

@typing_extensions.final
class Namespaces(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALTERNATE_NAME_FIELD_NUMBER: builtins.int
    DISABLE_LOCAL_AUTH_FIELD_NUMBER: builtins.int
    ENCRYPTION_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    ZONE_REDUNDANT_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAMESPACES_NETWORK_RULE_SETS_FIELD_NUMBER: builtins.int
    NAMESPACES__AUTHORIZATION_RULES_FIELD_NUMBER: builtins.int
    NAMESPACES_DISASTER_RECOVERY_CONFIGS_FIELD_NUMBER: builtins.int
    NAMESPACES_MIGRATION_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    MINIMUM_TLS_VERSION_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___Identity: ...
    location: builtins.str
    name: builtins.str
    alternate_name: builtins.str
    disable_local_auth: builtins.bool
    @property
    def encryption(self) -> global___Encryption: ...
    @property
    def private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateEndpointConnection]: ...
    zone_redundant: builtins.bool
    @property
    def sku(self) -> global___SBSku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def namespaces_network_rule_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesNetworkRuleSets]: ...
    @property
    def namespaces__authorization_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesAuthorizationRules]: ...
    @property
    def namespaces_disaster_recovery_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesDisasterRecoveryConfigs]: ...
    @property
    def namespaces_migration_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NamespacesMigrationConfigurations]: ...
    minimum_tls_version: builtins.str
    public_network_access: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___Identity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        alternate_name: builtins.str = ...,
        disable_local_auth: builtins.bool = ...,
        encryption: global___Encryption | None = ...,
        private_endpoint_connections: collections.abc.Iterable[global___PrivateEndpointConnection] | None = ...,
        zone_redundant: builtins.bool = ...,
        sku: global___SBSku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        namespaces_network_rule_sets: collections.abc.Iterable[global___NamespacesNetworkRuleSets] | None = ...,
        namespaces__authorization_rules: collections.abc.Iterable[global___NamespacesAuthorizationRules] | None = ...,
        namespaces_disaster_recovery_configs: collections.abc.Iterable[global___NamespacesDisasterRecoveryConfigs] | None = ...,
        namespaces_migration_configurations: collections.abc.Iterable[global___NamespacesMigrationConfigurations] | None = ...,
        minimum_tls_version: builtins.str = ...,
        public_network_access: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryption", b"encryption", "identity", b"identity", "resource_info", b"resource_info", "sku", b"sku"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alternate_name", b"alternate_name", "disable_local_auth", b"disable_local_auth", "encryption", b"encryption", "identity", b"identity", "location", b"location", "minimum_tls_version", b"minimum_tls_version", "name", b"name", "namespaces__authorization_rules", b"namespaces__authorization_rules", "namespaces_disaster_recovery_configs", b"namespaces_disaster_recovery_configs", "namespaces_migration_configurations", b"namespaces_migration_configurations", "namespaces_network_rule_sets", b"namespaces_network_rule_sets", "private_endpoint_connections", b"private_endpoint_connections", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "zone_redundant", b"zone_redundant"]) -> None: ...

global___Namespaces = Namespaces

@typing_extensions.final
class SBSku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    name: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        name: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "name", b"name", "tier", b"tier"]) -> None: ...

global___SBSku = SBSku

@typing_extensions.final
class PrivateEndpointConnection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___ConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___ConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state"]) -> None: ...

global___PrivateEndpointConnection = PrivateEndpointConnection

@typing_extensions.final
class ConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "status", b"status"]) -> None: ...

global___ConnectionState = ConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class Encryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_SOURCE_FIELD_NUMBER: builtins.int
    KEY_VAULT_PROPERTIES_FIELD_NUMBER: builtins.int
    REQUIRE_INFRASTRUCTURE_ENCRYPTION_FIELD_NUMBER: builtins.int
    key_source: builtins.str
    @property
    def key_vault_properties(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___KeyVaultProperties]: ...
    require_infrastructure_encryption: builtins.bool
    def __init__(
        self,
        *,
        key_source: builtins.str = ...,
        key_vault_properties: collections.abc.Iterable[global___KeyVaultProperties] | None = ...,
        require_infrastructure_encryption: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_source", b"key_source", "key_vault_properties", b"key_vault_properties", "require_infrastructure_encryption", b"require_infrastructure_encryption"]) -> None: ...

global___Encryption = Encryption

@typing_extensions.final
class KeyVaultProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTITY_FIELD_NUMBER: builtins.int
    KEY_NAME_FIELD_NUMBER: builtins.int
    KEY_VAULT_URI_FIELD_NUMBER: builtins.int
    KEY_VERSION_FIELD_NUMBER: builtins.int
    @property
    def identity(self) -> global___UserAssignedIdentityProperties: ...
    key_name: builtins.str
    key_vault_uri: builtins.str
    key_version: builtins.str
    def __init__(
        self,
        *,
        identity: global___UserAssignedIdentityProperties | None = ...,
        key_name: builtins.str = ...,
        key_vault_uri: builtins.str = ...,
        key_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "key_name", b"key_name", "key_vault_uri", b"key_vault_uri", "key_version", b"key_version"]) -> None: ...

global___KeyVaultProperties = KeyVaultProperties

@typing_extensions.final
class UserAssignedIdentityProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ASSIGNED_IDENTITY_FIELD_NUMBER: builtins.int
    user_assigned_identity: builtins.str
    def __init__(
        self,
        *,
        user_assigned_identity: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_assigned_identity", b"user_assigned_identity"]) -> None: ...

global___UserAssignedIdentityProperties = UserAssignedIdentityProperties

@typing_extensions.final
class Identity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___Identity = Identity



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Event(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    API_VERSION_FIELD_NUMBER: builtins.int
    DEPRECATED_COUNT_FIELD_NUMBER: builtins.int
    DEPRECATED_FIRST_TIMESTAMP_FIELD_NUMBER: builtins.int
    DEPRECATED_LAST_TIMESTAMP_FIELD_NUMBER: builtins.int
    DEPRECATED_SOURCE_FIELD_NUMBER: builtins.int
    EVENT_TIME_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NOTE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    REGARDING_FIELD_NUMBER: builtins.int
    RELATED_FIELD_NUMBER: builtins.int
    REPORTING_CONTROLLER_FIELD_NUMBER: builtins.int
    REPORTING_INSTANCE_FIELD_NUMBER: builtins.int
    SERIES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    action: builtins.str
    api_version: builtins.str
    deprecated_count: builtins.int
    @property
    def deprecated_first_timestamp(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def deprecated_last_timestamp(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def deprecated_source(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.EventSource: ...
    @property
    def event_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    note: builtins.str
    reason: builtins.str
    @property
    def regarding(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ObjectReference: ...
    @property
    def related(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ObjectReference: ...
    reporting_controller: builtins.str
    reporting_instance: builtins.str
    @property
    def series(self) -> global___EventSeries: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        api_version: builtins.str = ...,
        deprecated_count: builtins.int = ...,
        deprecated_first_timestamp: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        deprecated_last_timestamp: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        deprecated_source: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.EventSource | None = ...,
        event_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        note: builtins.str = ...,
        reason: builtins.str = ...,
        regarding: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ObjectReference | None = ...,
        related: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ObjectReference | None = ...,
        reporting_controller: builtins.str = ...,
        reporting_instance: builtins.str = ...,
        series: global___EventSeries | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deprecated_first_timestamp", b"deprecated_first_timestamp", "deprecated_last_timestamp", b"deprecated_last_timestamp", "deprecated_source", b"deprecated_source", "event_time", b"event_time", "metadata", b"metadata", "regarding", b"regarding", "related", b"related", "resource_info", b"resource_info", "series", b"series"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "api_version", b"api_version", "deprecated_count", b"deprecated_count", "deprecated_first_timestamp", b"deprecated_first_timestamp", "deprecated_last_timestamp", b"deprecated_last_timestamp", "deprecated_source", b"deprecated_source", "event_time", b"event_time", "kind", b"kind", "metadata", b"metadata", "note", b"note", "reason", b"reason", "regarding", b"regarding", "related", b"related", "reporting_controller", b"reporting_controller", "reporting_instance", b"reporting_instance", "resource_info", b"resource_info", "series", b"series", "type", b"type"]) -> None: ...

global___Event = Event

@typing_extensions.final
class EventList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Event]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Event] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___EventList = EventList

@typing_extensions.final
class EventSeries(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    LAST_OBSERVED_TIME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    count: builtins.int
    @property
    def last_observed_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        count: builtins.int = ...,
        last_observed_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.MicroTime | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_observed_time", b"last_observed_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "last_observed_time", b"last_observed_time", "resource_info", b"resource_info"]) -> None: ...

global___EventSeries = EventSeries



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_fms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_fms.proto\x12\x13oak9.tython.aws.fms\x1a\x13shared/shared.proto\"|\n\x13NotificationChannel\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rsns_role_name\x18\x02 \x01(\t\x12\x15\n\rsns_topic_arn\x18\x03 \x01(\t\"z\n\x03\x46MS\x12\x46\n\x14notification_channel\x18\x01 \x03(\x0b\x32(.oak9.tython.aws.fms.NotificationChannel\x12+\n\x06policy\x18\x02 \x03(\x0b\x32\x1b.oak9.tython.aws.fms.Policy\"h\n\x0bPolicyIEMap\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x61\x63\x63ount\x18\x02 \x03(\t\x12\x0f\n\x07orgunit\x18\x03 \x03(\t\"h\n\x11PolicyResourceTag\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"f\n\x0fPolicyPolicyTag\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xef\x04\n\x06Policy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x35\n\x0b\x65xclude_map\x18\x02 \x01(\x0b\x32 .oak9.tython.aws.fms.PolicyIEMap\x12\x1d\n\x15\x65xclude_resource_tags\x18\x03 \x01(\x08\x12\x35\n\x0binclude_map\x18\x04 \x01(\x0b\x32 .oak9.tython.aws.fms.PolicyIEMap\x12\x13\n\x0bpolicy_name\x18\x05 \x01(\t\x12\x1b\n\x13remediation_enabled\x18\x06 \x01(\x08\x12=\n\rresource_tags\x18\x07 \x03(\x0b\x32&.oak9.tython.aws.fms.PolicyResourceTag\x12\x15\n\rresource_type\x18\x08 \x01(\t\x12\x1a\n\x12resource_type_list\x18\t \x03(\t\x12`\n\x1csecurity_service_policy_data\x18\n \x03(\x0b\x32:.oak9.tython.aws.fms.Policy.SecurityServicePolicyDataEntry\x12#\n\x1b\x64\x65lete_all_policy_resources\x18\x0b \x01(\x08\x12\x32\n\x04tags\x18\x0c \x03(\x0b\x32$.oak9.tython.aws.fms.PolicyPolicyTag\x1a@\n\x1eSecurityServicePolicyDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_fms_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _POLICY_SECURITYSERVICEPOLICYDATAENTRY._options = None
  _POLICY_SECURITYSERVICEPOLICYDATAENTRY._serialized_options = b'8\001'
  _NOTIFICATIONCHANNEL._serialized_start=63
  _NOTIFICATIONCHANNEL._serialized_end=187
  _FMS._serialized_start=189
  _FMS._serialized_end=311
  _POLICYIEMAP._serialized_start=313
  _POLICYIEMAP._serialized_end=417
  _POLICYRESOURCETAG._serialized_start=419
  _POLICYRESOURCETAG._serialized_end=523
  _POLICYPOLICYTAG._serialized_start=525
  _POLICYPOLICYTAG._serialized_end=627
  _POLICY._serialized_start=630
  _POLICY._serialized_end=1253
  _POLICY_SECURITYSERVICEPOLICYDATAENTRY._serialized_start=1189
  _POLICY_SECURITYSERVICEPOLICYDATAENTRY._serialized_end=1253
# @@protoc_insertion_point(module_scope)



import core.sdk.helper as Helper
import requests
import time
from core.types import Finding, Configuration
from models.shared.shared_pb2 import RunnerInput



class TythonApiService:
    """
    Provides access to the tython api
    """

    @staticmethod
    def get_default_environment(config: Configuration):
        """
        Gets the default environment_id
        """
        url = f"{config.data_endpoint}{config.org_id}/projectEnvironment/{config.project_id}/default"
        response = requests.get(url, auth=(config.org_id, config.api_key))

        if response.status_code != 200:
            raise Exception("Unable to get default environment, verify your credentials.")

        environment_result = response.json()
        environment_id = "" if "projectId" not in environment_result else environment_result["projectId"]

        if not environment_id:
            raise Exception("Unable to get default environment, verify your credentials.")

        return environment_id


    @staticmethod
    def build_app(config: Configuration, environment_id: str):
        """
        Triggers build app endpoint
        """
        url = f"{config.data_endpoint}{config.org_id}/sac/{config.project_id}/build/{environment_id}"
        response = requests.post(url, auth=(config.org_id, config.api_key))

        if response.status_code != 200:
            raise Exception("Unable to trigger build app, verify your credentials.")

        build_app_result = response.json()
        request_id = "" if "requestId" not in build_app_result else build_app_result["requestId"]

        return request_id


    @staticmethod
    def fetch_graph_data(config: Configuration, environment_id: str, request_id: str):
        """
        Fetch projects graph data
        """
        url = f"{config.data_endpoint}{config.org_id}/sac/{config.project_id}/resourcegraph/{environment_id}/{request_id}"
        timeout = 600
        poll_interval = 15
        start_time = time.time()
        while True:
            response = requests.get(url, auth=(config.org_id, config.api_key))
            if response.status_code == 200:
                break
            elif time.time() - start_time > timeout:
                raise Exception(f"Unable to fetch {config.project_id} data, please verify your credentials.")
            time.sleep(poll_interval)

        runner_inputs = []

        raw_snake_case_input = Helper.snake_case_json(response.json())

        for raw_item in raw_snake_case_input:
            item = raw_item['item1']
            for root_node in item['graph']['root_nodes']:
                root_node['node']['resource']['data']['value'] = bytes(root_node['node']['resource']['data']['value'])
            Helper.remove_attributes(item, "has_")
            runner_inputs.append(RunnerInput(**item))

        return runner_inputs


    @staticmethod
    def apply_findings(config: Configuration, findings: list[Finding], environment_id: str, request_id: str):
        """
        Apply a findings list to the oak9 project
        """
        design_gaps = []
        capability_number = 1

        for finding in findings:
            if finding:
                violation = finding.to_violation()
                design_gaps.append(
                    {
                        "capabilityId": f"{config.org_id}.{capability_number}",
                        "capabilityName": finding.desc,
                        "source": "",
                        "resourceName": finding.resource_metadata.resource_name,
                        "resourceId": finding.resource_metadata.resource_id,
                        "resourceType": finding.resource_metadata.resource_type,
                        "resourceGap": "",
                        "resourceImpact": "",
                        "violations": [violation.__json__()],
                        "oak9Guidance": "",
                        "mappedIndustryFrameworks": []
                    }
                )
                capability_number += 1

        payload = {
            "runtime": "Python",
            "author": "",
            "designGaps": design_gaps
        }

        url = f"{config.data_endpoint}{config.org_id}/sac/{config.project_id}/apply/{environment_id}/{request_id}"
        response = requests.post(url, auth=(config.org_id, config.api_key), json=payload)

        if response.status_code != 200:
            raise Exception(f"Unable to apply {config.project_id} findings, please verify your credentials.")

        # TODO: handle response details
